pub fn markup_from_article(doc: &Expr) -> Result<MarkupDoc>Expand description
Convert a canonical or compatibility article expression into markup.
Errors
Returns an error when the expression is neither a MarkupDoc value nor a
compatibility article value.